@@ -135,6 +135,8 @@ int main(int argc, char ** argv){
 	CORBA_string source_disp = NULL;
 
 	CORBA_exception_init (&ev);
+
+	float R, G, B;
 	
 	if (!bonobo_init (&argc, argv))
 	{
@@ -222,6 +224,15 @@ int main(int argc, char ** argv){
 	case 'x':
 		GNOME_Magnifier_Magnifier_dispose (magnifier, &ev);
 		break;
+	case 'C':
+		GNOME_Magnifier_ZoomRegion_setContrast (zoom_region,
+							atof (argv[2]),
+							atof (argv[3]),
+							atof (argv[4]),
+							&ev);
+		GNOME_Magnifier_ZoomRegion_getContrast (zoom_region, &R, &G, &B, &ev);
+		printf ("ZoomRegion R, G, B: %f, %f, %f\n", R, G, B);
+		break;
         case 'S':
 		properties = GNOME_Magnifier_Magnifier_getProperties (magnifier, &ev);
 		bonobo_pbclient_set_long (properties, "cursor-size", 200, NULL);
